@@ -135,7 +135,7 @@ import string
 import threading
 
 from botocore.compat import six  # noqa: F401
-from botocore.exceptions import IncompleteReadError
+from botocore.exceptions import IncompleteReadError, ResponseStreamingError
 from botocore.vendored.requests.packages.urllib3.exceptions import (
     ReadTimeoutError,
 )
@@ -144,7 +144,7 @@ import s3transfer.compat
 from s3transfer.exceptions import RetriesExceededError, S3UploadFailedError
 
 __author__ = 'Amazon Web Services'
-__version__ = '0.7.0'
+__version__ = '0.10.2'
 
 
 class NullHandler(logging.Handler):
@@ -624,6 +624,7 @@ class MultipartDownloader:
                     OSError,
                     ReadTimeoutError,
                     IncompleteReadError,
+                    ResponseStreamingError,
                 ) as e:
                     logger.debug(
                         "Retrying exception caught (%s), "
@@ -681,7 +682,6 @@ class TransferConfig:
 
 
 class S3Transfer:
-
     ALLOWED_DOWNLOAD_ARGS = [
         'VersionId',
         'SSECustomerAlgorithm',
@@ -841,6 +841,7 @@ class S3Transfer:
                 OSError,
                 ReadTimeoutError,
                 IncompleteReadError,
+                ResponseStreamingError,
             ) as e:
                 # TODO: we need a way to reset the callback if the
                 # download failed.
